@@ -9,10 +9,8 @@ class InstanceAssertions(object):
 
     def instanceof(self, exp):
         res = isinstance(self._val, exp)
-        if self._not:
-            res = not res
-        msg = '{0} should {1}be instance of {2}'.format
-        self._assert(res, msg(self._val, self._flag, exp))
+        msg = '{0} should be instance of {1}'.format
+        self._assert(res, msg(self._val, exp))
         return self
 
 
@@ -21,9 +19,9 @@ def type_assert(exp, self):
     exp 会做偏函数, 所以对象会被绑定在第二个参数上
     '''
     actual = type(self._val)
-    res = (actual is not exp) if self._not else (actual is exp)
-    msg_format = '{0} should be {1}{2}'.format
-    self._assert(res, msg_format(actual, self._flag, exp))
+    res = actual is exp
+    msg_format = '{0} should be {1}'.format
+    self._assert(res, msg_format(actual, exp))
     return self
 
 
