@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
+__all__ = ['ValueAssertions']
+
 
 class ValueAssertions(object):
 
     def equal(self, exp):
         res = self._val == exp
-        if self._flag:
-            res = not res
-        msg = '{0} should {1}be equal to {2}'.format
-        self._assert(res, msg(self._val, self._flag, exp))
+        msg = '{0} should be equal to {1}'.format
+        self._assert(res, msg(self._val, exp))
         return self
 
     @property
@@ -29,9 +29,9 @@ class ValueAssertions(object):
         return self
 
     def __values(self, exp, actual):
-        res = (actual is not exp) if self._not else (actual is exp)
-        msg_format = '{0} should be {1}{2}'.format
-        return res, msg_format(actual, self._flag, exp)
+        res = actual is exp
+        msg_format = '{0} should be {1}'.format
+        return res, msg_format(actual, exp)
 
     @property
     def ok(self):
@@ -46,6 +46,6 @@ class ValueAssertions(object):
         return self
 
     def _ok(self, actual):
-        res = not bool(actual) if self._not else bool(actual)
-        msg_format = '{0}\'s bool value is {1}True'.format
-        return res, msg_format(actual, self._flag)
+        res = bool(actual)
+        msg_format = '{0}\'s bool value should be True'.format
+        return res, msg_format(actual)
