@@ -32,14 +32,19 @@ class Should(object):
         self._not = True
         return self
 
-    def _assert(self, res, msg):
-        ''' 统一的 assert 方法, 每次断言之后取消取否 '''
-        assert res, msg
+    def _reset(self):
         self._not = False
+        return self
 
-    @property
-    def _flag(self):
-        return 'not ' if self._not else ''
+    def _assert(self, res, msg, reset=True):
+        ''' 统一的 assert 方法, 每次断言之后取消取否 '''
+        if self._not:
+            res = not res
+            msg = msg.replace('should', 'should not')
+        assert res, msg
+        if reset:
+            self._reset()
+        return self
 
     def use(self, cls):
         origin = self.__class__
